@@ -2,7 +2,15 @@
 # Stub file for mods development in Assetto Corsa
 #
 
-def getCarState(car_identifier, info_identifier, optional_identifier): ...
+def getCarState(car_identifier, info_identifier, optional_identifier=None):
+    """
+    :param car_identifier: int
+    :param info_identifier: Any appropriate type
+    :param optional_identifier: Any: The optional identifier can be omitted, it is used for special infos where they
+                                require a specific tyre, as described in the following section.
+    :returns the info_identifier type of information associated to car car_identifier.
+    """
+    pass
 
 
 def log(value): ...
@@ -200,22 +208,22 @@ def getCarPowerControllerCount(): ...
 def freeCameraSetClearColor(r, g, b, alpha): ...
 
 
-def freeCameraMoveForward(float): ...
+def freeCameraMoveForward(_float): ...
 
 
-def freeCameraMoveRight(float): ...
+def freeCameraMoveRight(_float): ...
 
 
-def freeCameraMoveUpWorld(float): ...
+def freeCameraMoveUpWorld(_float): ...
 
 
-def freeCameraRotatePitch(float): ...
+def freeCameraRotatePitch(_float): ...
 
 
-def freeCameraRotateHeading(float): ...
+def freeCameraRotateHeading(_float): ...
 
 
-def freeCameraRotateRoll(float): ...
+def freeCameraRotateRoll(_float): ...
 
 
 def sendChatMessage(string_msg): ...
@@ -225,4 +233,9 @@ def addOnChatMessageListener(ac_window_id, call_back_function): ...
 
 
 # Get focused car ID
-def getFocusedCar() -> int: ...
+def getFocusedCar():
+    """
+    Get focused car ID
+    :return: int
+    """
+    pass
